@@ -2,7 +2,7 @@
  * GChemPaint GOffice component
  * gofficeapp.cc
  *
- * Copyright (C) 2005-2006 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2005-2007 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -25,6 +25,7 @@
 #include "gofficeapp.h"
 #include "gofficewin.h"
 #include <lib/document.h>
+#include <glib/gi18n-lib.h>
 
 gcpGOfficeApplication::gcpGOfficeApplication (): gcpApplication ()
 {
@@ -81,7 +82,6 @@ bool gcpGOfficeApplication::EditDocument (GOGChemPaintComponent *gogcp)
 		win = new gcpGOfficeWindow (this, gogcp);
 		if (!win)
 			return false;
-		AddDocument (win->GetDocument ());
 		return true;
 	}
 	catch (int i) {
@@ -91,13 +91,13 @@ bool gcpGOfficeApplication::EditDocument (GOGChemPaintComponent *gogcp)
 	}
 }
 
-void gcpGOfficeApplication::OnFileNew ()
+void gcpGOfficeApplication::OnFileNew (char const *Theme)
 {
 	gchar tmp[32];
 	if (m_pActiveDoc && !m_pActiveDoc->GetView ()->PrepareUnselect ())
 		return;
 	g_snprintf (tmp, sizeof (tmp), _("Untitled %d"), m_NumWindow++);
-	new gcpWindow (this);
+	new gcpWindow (this, Theme);
 }
 
 void gcpGOfficeApplication::OnFileClose ()
