@@ -4,9 +4,7 @@
  * GChemPaint library
  * molecule.h 
  *
- * Copyright (C) 2001-2005
- *
- * Developed by Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2001-2007 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -38,6 +36,7 @@ public:
 	gcpMolecule(TypeId Type = MoleculeType);
 	gcpMolecule(gcpAtom* pAtom);
 	virtual ~gcpMolecule();
+	void Add (GtkWidget* w);
 	void AddAtom(gcpAtom* pAtom);
 	void AddFragment(gcpFragment* pFragment);
 	void AddBond(gcpBond* pBond);
@@ -58,10 +57,13 @@ public:
 	void SelectAlignmentItem (Object *child);
 	string GetAlignmentId () {return (m_Alignment)? m_Alignment->GetId (): "";}
 	void BuildOBMol (OBMol &Mol);
+	void BuildOBMol2D (OBMol &Mol);
 	void ShowInChI ();
 	void BuildInChI ();
 	void BuildSmiles ();
-	void ShowWebbook ();
+	void ShowWebBase (char const *uri_start, char const *uri_end);
+	void OpenCalc ();
+	void CheckCrossings (gcpBond *pBond);
 
 private:
 	list<gcpCycle*> m_Cycles;
