@@ -4,7 +4,7 @@
  * GChemPaint library
  * reactant.cc 
  *
- * Copyright (C) 2002-2006 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2002-2007 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -29,7 +29,7 @@
 #include "document.h"
 #include "text.h"
 #include "theme.h"
-#include <glib/gi18n.h>
+#include <glib/gi18n-lib.h>
 
 extern xmlDocPtr pXmlDoc;
 
@@ -168,6 +168,7 @@ void gcpReactant::AddStoichiometry ()
 	Stoichiometry = text;
 	AddChild (text);
 	pDoc->AddObject (text);
+	gnome_canvas_update_now (GNOME_CANVAS (pData->Canvas));
 	pData->GetObjectBounds (text, &rect);
 	Child->Move (rect.x1 / pTheme->GetZoomFactor () + pTheme->GetStoichiometryPadding () - x, 0.);
 	gcpTool *tool = pApp->GetTool ("Text");
@@ -206,10 +207,8 @@ bool gcpReactant::OnSignal (SignalId Signal, Object *Obj)
 			double x = rect.x1 / pTheme->GetZoomFactor () + pTheme->GetStoichiometryPadding ();
 			pData->GetObjectBounds (Child, &rect);
 			Child->Move (x - rect.x0 / pTheme->GetZoomFactor (), 0.);
-			GtkTextBuffer *buf = (GtkTextBuffer*) ((gcpTextObject*) Stoichiometry)->GetTextBuffer ();
-			GtkTextIter start, end;
-			gtk_text_buffer_get_bounds (buf, &start, &end);
-			const char *txt = gtk_text_buffer_get_text (buf, &start, &end, true);
+			PangoLayout *layout = ((gcpTextObject*) Stoichiometry)->GetLayout ();
+			const char *txt = pango_layout_get_text (layout);
 			char *endptr;
 			int n = strtol (txt, &endptr, 10);
 			m_Stoich = (!*endptr)? n: 0;
