@@ -4,9 +4,7 @@
  * GChemPaint library
  * reaction-operator.cc 
  *
- * Copyright (C) 2004
- *
- * Developed by Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2004-2006 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -27,6 +25,8 @@
 #include "gchempaint-config.h"
 #include "reaction-operator.h"
 #include "settings.h"
+#include "document.h"
+#include "theme.h"
 #include "view.h"
 #include "widgetdata.h"
 #include "libgcpcanvas/gcp-canvas-group.h"
@@ -47,12 +47,12 @@ void gcpReactionOperator::Add (GtkWidget* w)
 	if (!w)
 		return;
 	gcpWidgetData* pData = (gcpWidgetData*) g_object_get_data (G_OBJECT (w), "data");
+	gcpTheme *pTheme = pData->View->GetDoc ()->GetTheme ();
 	double x, y;
 	GetCoords (&x, &y);
-	x *= pData->ZoomFactor;
-	y *= pData->ZoomFactor;
+	x *= pTheme->GetZoomFactor ();
+	y *= pTheme->GetZoomFactor ();
 	double dFontHeight = pData->View->GetFontHeight ();
-	char * szFontName = pData->View->GetFontName ();
 	GnomeCanvasItem* item;
 	GnomeCanvasGroup* group;
 	gint width, height;
@@ -71,10 +71,10 @@ void gcpReactionOperator::Add (GtkWidget* w)
 	item = gnome_canvas_item_new (
 						group,
 						gnome_canvas_rect_ext_get_type (),
-						"x1", x - (double) width / 2 - pData->Padding,
-						"y1", y - dFontHeight / 2 - pData->Padding,
-						"x2", x + (double) width / 2 + pData->Padding,
-						"y2", y + dFontHeight / 2 + pData->Padding,
+						"x1", x - (double) width / 2 - pTheme->GetPadding (),
+						"y1", y - dFontHeight / 2 - pTheme->GetPadding (),
+						"x2", x + (double) width / 2 + pTheme->GetPadding (),
+						"y2", y + dFontHeight / 2 + pTheme->GetPadding (),
 						"fill_color", "white",
 						NULL);
 	g_signal_connect (G_OBJECT (item), "event", G_CALLBACK (on_event), w);
@@ -99,10 +99,11 @@ void gcpReactionOperator::Update (GtkWidget* w)
 	if (!w)
 		return;
 	gcpWidgetData* pData = (gcpWidgetData*) g_object_get_data (G_OBJECT (w), "data");
+	gcpTheme *pTheme = pData->View->GetDoc ()->GetTheme ();
 	double x, y;
 	GetCoords (&x, &y);
-	x *= pData->ZoomFactor;
-	y *= pData->ZoomFactor;
+	x *= pTheme->GetZoomFactor ();
+	y *= pTheme->GetZoomFactor ();
 	double dFontHeight = pData->View->GetFontHeight ();
 	GnomeCanvasItem* item;
 	GnomeCanvasGroup* group = pData->Items[this];
@@ -117,10 +118,10 @@ void gcpReactionOperator::Update (GtkWidget* w)
 	height =  rect.height / PANGO_SCALE;
 	item = (GnomeCanvasItem*) g_object_get_data (G_OBJECT (group), "background");
 	g_object_set (G_OBJECT (item),
-						"x1", x - (double) width / 2 - pData->Padding,
-						"y1", y - dFontHeight / 2 - pData->Padding,
-						"x2", x + (double) width / 2 + pData->Padding,
-						"y2", y + dFontHeight / 2 + pData->Padding,
+						"x1", x - (double) width / 2 - pTheme->GetPadding (),
+						"y1", y - dFontHeight / 2 - pTheme->GetPadding (),
+						"x2", x + (double) width / 2 + pTheme->GetPadding (),
+						"y2", y + dFontHeight / 2 + pTheme->GetPadding (),
 						NULL);
 	item = (GnomeCanvasItem*) g_object_get_data (G_OBJECT (group), "text");
 	g_object_set (G_OBJECT (item),
