@@ -4,9 +4,7 @@
  * GChemPaint library
  * reaction.cc 
  *
- * Copyright (C) 2002-2005
- *
- * Developed by Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2002-2007 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -29,7 +27,9 @@
 #include "reaction-arrow.h"
 #include "reaction-step.h"
 #include "document.h"
+#include "theme.h"
 #include "view.h"
+#include <glib/gi18n-lib.h>
 #include <math.h>
 
 gcpReaction::gcpReaction (): Object (ReactionType)
@@ -46,7 +46,7 @@ gcpReaction::~gcpReaction ()
 	gcpReactionArrow *arrow;
 	gcpDocument *pDoc = reinterpret_cast<gcpDocument *> (GetDocument ());
 	gcpOperation *pOp = pDoc->GetCurrentOperation ();
-	while (pObj = GetFirstChild (i)) {
+	while ((pObj = GetFirstChild (i))) {
 		if (pObj->GetType () == ReactionArrowType) {
 			arrow = reinterpret_cast<gcpReactionArrow*> (pObj);
 			arrow->SetStartStep (NULL);
@@ -60,21 +60,10 @@ gcpReaction::~gcpReaction ()
 	}
 }
 
-void gcpReaction::Add (GtkWidget* w)
-{
-	map<string, Object*>::iterator i;
-	Object* p = GetFirstChild (i);
-	while (p)
-	{
-		p->Add (w);
-		p = GetNextChild (i);
-	}
-}
-
 bool gcpReaction::Build (list<Object*>& Children) throw (invalid_argument)
 {
 	gcpDocument *pDoc = (gcpDocument*) GetDocument ();
-	gcpView *pView = pDoc->GetView ();
+	gcpTheme *pTheme = pDoc->GetTheme ();
 	gcpWidgetData  *pData= (gcpWidgetData*)g_object_get_data(G_OBJECT(pDoc->GetWidget ()), "data");
 	map<Object*, ArtDRect> Objects;
 	list<Object*>::iterator i, end = Children.end ();
@@ -105,8 +94,8 @@ bool gcpReaction::Build (list<Object*>& Children) throw (invalid_argument)
 		// x1, y1 will now be the coordinates of a normalized vector:
 		x1 -= x0;
 		y1 -= y0;
-		x0 *= pData->ZoomFactor;
-		y0 *= pData->ZoomFactor;
+		x0 *= pTheme->GetZoomFactor ();
+		y0 *= pTheme->GetZoomFactor ();
 		l = sqrt (x1 * x1 + y1 * y1);
 		x1 /= l;
 		y1 /= l;
@@ -148,7 +137,7 @@ bool gcpReaction::Build (list<Object*>& Children) throw (invalid_argument)
 			// Move the arrow to its new position
 			pData->GetObjectBounds (step, &srect);
 			x0 = (srect.x0 + srect.x1) / 2;
-			y0 = step->GetYAlign () * pData->ZoomFactor;
+			y0 = step->GetYAlign () * pTheme->GetZoomFactor ();
 			x = srect.x1 - x0;
 			y = srect.y1 - y0;
 			if ((fabs (x1) > 1e-5) && (fabs (y1) > 1e-5))
@@ -158,20 +147,20 @@ bool gcpReaction::Build (list<Object*>& Children) throw (invalid_argument)
 			else
 				horiz = false;
 			if (horiz) {
-				l = x + pView->GetArrowPadding () * pData->ZoomFactor;
+				l = x + pTheme->GetArrowPadding ();
 				if (x1 < 0)
 					l = -l;
 				x0 += l;
 				y0 += l * y1 / x1;
 			} else {
-				l = y + pView->GetArrowPadding () * pData->ZoomFactor;
+				l = y + pTheme->GetArrowPadding ();
 				if (y1 < 0)
 					l = -l;
 				x0 += l * x1 / y1;
 				y0 += l;
 			}
 			arrow->GetCoords (&srect.x0, &srect.y0, &srect.x1, &srect.y1);
-			arrow->Move (x0 / pData->ZoomFactor - srect.x0, y0 / pData->ZoomFactor - srect.y0);
+			arrow->Move (x0 / pTheme->GetZoomFactor () - srect.x0, y0 / pTheme->GetZoomFactor () - srect.y0);
 		}
 		arrow->GetCoords (&srect.x0, &srect.y0, &srect.x1, &srect.y1);
 		xpos = srect.x1;
@@ -182,7 +171,7 @@ bool gcpReaction::Build (list<Object*>& Children) throw (invalid_argument)
 			arrow->SetEndStep (step);
 			pData->GetObjectBounds (step, &srect);
 			x0 = (srect.x0 + srect.x1) / 2;
-			y0 = step->GetYAlign () * pData->ZoomFactor;
+			y0 = step->GetYAlign () * pTheme->GetZoomFactor ();
 			if (l == 0.) {
 				if ((fabs (x1) > 1e-5) && (fabs (y1) > 1e-5))
 					horiz = (fabs (x1) > fabs (y1));
@@ -193,20 +182,20 @@ bool gcpReaction::Build (list<Object*>& Children) throw (invalid_argument)
 			}
 			if (horiz) {
 				x = srect.x1 - x0;
-				l = x + pView->GetArrowPadding () * pData->ZoomFactor;
+				l = x + pTheme->GetArrowPadding ();
 				if (x1 < 0)
 					l = -l;
 				x0 -= l;
 				y0 -= l * y1 / x1;
 			} else {
 				y = srect.y1 - y0;
-				l = y + pView->GetArrowPadding () * pData->ZoomFactor;
+				l = y + pTheme->GetArrowPadding ();
 				if (y1 < 0)
 					l = -l;
 				x0 -= l * x1 / y1;
 				y0 -= l;
 			}
-			step->Move (xpos - x0 / pData->ZoomFactor, ypos - y0 / pData->ZoomFactor);
+			step->Move (xpos - x0 / pTheme->GetZoomFactor (), ypos - y0 / pTheme->GetZoomFactor ());
 		}
 	} else
 		throw  invalid_argument (_("Error could not build a reaction\nfrom the selected objects."));
@@ -224,6 +213,7 @@ bool gcpReaction::OnSignal (SignalId Signal, Object *Obj)
 	if (Signal == OnChangedSignal) {
 		gcpDocument *pDoc = (gcpDocument*) GetDocument ();
 		gcpView *pView = pDoc->GetView ();
+		gcpTheme *pTheme = pDoc->GetTheme ();
 		gcpWidgetData  *pData= (gcpWidgetData*)g_object_get_data(G_OBJECT(pDoc->GetWidget ()), "data");
 		map<Object*, ArtDRect> Objects;
 		map<double, Object*> Children;
@@ -258,24 +248,24 @@ bool gcpReaction::OnSignal (SignalId Signal, Object *Obj)
 					has_start = true;
 					pData->GetObjectBounds (step, &rect);
 					x2 = (rect.x0 + rect.x1) / 2;
-					y2 = step->GetYAlign () * pData->ZoomFactor;
+					y2 = step->GetYAlign () * pTheme->GetZoomFactor ();
 					xpos = rect.x1 - x2;
 					ypos = rect.y1 - y2;
 					if (horiz) {
-						l = xpos + pView->GetArrowPadding () * pData->ZoomFactor;
+						l = xpos + pTheme->GetArrowPadding ();
 						if (x < 0)
 							l = -l;
 						x2 += l;
 						y2 += l * y / x;
 					} else {
-						l = ypos + pView->GetArrowPadding () * pData->ZoomFactor;
+						l = ypos + pTheme->GetArrowPadding ();
 						if (y < 0)
 							l = -l;
 						x2 += l * x / y;
 						y2 += l;
 					}
-					x1 += xpos = x2 / pData->ZoomFactor - x0;
-					y1 += ypos = y2 / pData->ZoomFactor - y0;
+					x1 += xpos = x2 / pTheme->GetZoomFactor () - x0;
+					y1 += ypos = y2 / pTheme->GetZoomFactor () - y0;
 					arrow->Move (xpos, ypos);
 					pView->Update (arrow);
 				}
@@ -283,23 +273,23 @@ bool gcpReaction::OnSignal (SignalId Signal, Object *Obj)
 				if (step) {
 					pData->GetObjectBounds (step, &rect);
 					x2 = (rect.x0 + rect.x1) / 2;
-					y2 = step->GetYAlign () * pData->ZoomFactor;
+					y2 = step->GetYAlign () * pTheme->GetZoomFactor ();
 					if (horiz) {
 						xpos = rect.x1 - x2;
-						l = xpos + pView->GetArrowPadding () * pData->ZoomFactor;
+						l = xpos + pTheme->GetArrowPadding ();
 						if (x < 0)
 							l = -l;
 						x2 -= l;
 						y2 -= l * y / x;
 					} else {
 						ypos = rect.y1 - y2;
-						l = ypos + pView->GetArrowPadding () * pData->ZoomFactor;
+						l = ypos + pTheme->GetArrowPadding ();
 						if (y < 0)
 							l = -l;
 						x2 -= l * x / y;
 						y2 -= l;
 					}
-					step->Move (x1 - x2 / pData->ZoomFactor, y1 - y2 / pData->ZoomFactor);
+					step->Move (x1 - x2 / pTheme->GetZoomFactor (), y1 - y2 / pTheme->GetZoomFactor ());
 					pView->Update (step);
 				} else if (!has_start)
 					IsolatedArrows.push_front (arrow);
