@@ -36,6 +36,16 @@ xmlChar* ClipboardData = NULL;
 guint ClipboardDataType, ClipboardDataType1;
 bool cleared = true;
 
+GtkTargetEntry const export_targets[] = {
+	{(char *) GCHEMPAINT_ATOM_NAME,  0, 0},
+	{(char *) "image/svg",  0, 1},
+	{(char *) "image/svg+xml",  0, 2},
+	{(char *) "image/png",  0, 3},
+	{(char *) "image/jpeg",  0, 4},
+	{(char *) "UTF8_STRING", 0, 5},
+	{(char *) "STRING", 0, 6}
+};
+
 void on_receive_targets (GtkClipboard *clipboard, GtkSelectionData *selection_data, gcpApplication *App)
 {
 	GtkClipboard* sel_clipboard = gtk_clipboard_get (GDK_SELECTION_CLIPBOARD);
@@ -44,6 +54,10 @@ void on_receive_targets (GtkClipboard *clipboard, GtkSelectionData *selection_da
 		static char const *formats [] =
 		{
 			GCHEMPAINT_ATOM_NAME,
+			"image/svg",
+			"image/svg+xml",
+			"image/png",
+			"image/jpeg",
 			"UTF8_STRING",
 			"STRING",
 			NULL
@@ -55,12 +69,12 @@ void on_receive_targets (GtkClipboard *clipboard, GtkSelectionData *selection_da
 		/* Nothing on clipboard? */
 		if (selection_data->length < 0) {
 			if (clipboard == sel_clipboard)
-				App->ActivateMenu("Paste", false);
+				App->ActivateWindowsActionWidget ("/MainMenu/EditMenu/Paste", false);
 			return;
 		}
 
 		gchar* name;
-		*DataType = 3;
+		*DataType = 7;
 		for ( j = 0; j < atom_count ; j++) {
 			name = gdk_atom_name (targets [j]);
 			for (i = 0; i < *DataType; i++)
@@ -72,7 +86,8 @@ void on_receive_targets (GtkClipboard *clipboard, GtkSelectionData *selection_da
 		}
 	}
 	if (clipboard == sel_clipboard && App != NULL)
-		App->ActivateMenu ("Paste", ClipboardDataType < 3);
+		App->ActivateWindowsActionWidget ("/MainMenu/EditMenu/Paste",
+			ClipboardDataType == 0 || ClipboardDataType == 5 || ClipboardDataType == 6);
 }
 
 static void on_get_data(GtkClipboard *clipboard, GtkSelectionData *selection_data,  guint info, gcpApplication *App)
@@ -86,20 +101,36 @@ static void on_get_data(GtkClipboard *clipboard, GtkSelectionData *selection_dat
 	} 
 	*DataType = info;
 	gint size;
-	if (info)
-	{
-		xmlKeepBlanksDefault(0);
+	switch (info) {
+	case 0:
 		xmlDocDumpFormatMemory (pDoc, &ClipboardData, &size, info);
-		gtk_selection_data_set_text(selection_data, (const gchar*) ClipboardData, size);
-		xmlKeepBlanksDefault(1);
+		gtk_selection_data_set(selection_data, gdk_atom_intern (GCHEMPAINT_ATOM_NAME, FALSE), 8, (const guchar*) ClipboardData, size);
+		break;
+	case 1:
+	case 2: {
+		gcpDocument *Doc = new gcpDocument (NULL, true);
+		gcpView *pView = Doc->GetView ();
+		pView->CreateNewWidget (); // force canvas creation
+		Doc->ParseXMLTree (pDoc);
+		xmlDocPtr doc = pView->BuildSVG ();
+		xmlDocDumpFormatMemory (doc, &ClipboardData, &size, info);
+		gtk_selection_data_set (selection_data, gdk_atom_intern (export_targets[info].target, FALSE), 8, (const guchar*) ClipboardData, size);
+		xmlFreeDoc (doc);
+		delete Doc;
+		break;
 	}
-	else
-	{
+	case 3:
+		break;
+	case 4:
+		break;
+	default:
 		xmlDocDumpFormatMemory (pDoc, &ClipboardData, &size, info);
-		gtk_selection_data_set(selection_data, gdk_atom_intern (GCHEMPAINT_ATOM_NAME, FALSE), 8,  (const guchar*) ClipboardData, size);
+		gtk_selection_data_set_text (selection_data, (const gchar*) ClipboardData, size);
+		break;
 	}
 	cleared = false;
-	if (clipboard == gtk_clipboard_get(GDK_SELECTION_CLIPBOARD)) App->ActivateMenu("Paste", true);
+	if (clipboard == gtk_clipboard_get(GDK_SELECTION_CLIPBOARD))
+		App->ActivateWindowsActionWidget ("/MainMenu/EditMenu/Paste", true);
 }
 
 void on_clear_data(GtkClipboard *clipboard, gcpApplication *App)
@@ -207,6 +238,8 @@ void gcpWidgetData::Copy(GtkClipboard* clipboard)
 	if (!*pDoc) return;
 	if (SelectedObjects.empty()) return;
 	xmlDocSetRootElement (*pDoc, xmlNewDocNode(*pDoc, NULL, (xmlChar*)"chemistry", NULL));
+	xmlNsPtr ns = xmlNewNs ((*pDoc)->children, (xmlChar*) "http://www.nongnu.org/gchempaint", (xmlChar*) "gcp");
+	xmlSetNs ((*pDoc)->children, ns);
 //FIXME: implement exception handling
 	std::list<Object*>::iterator i;
 	xmlNodePtr child;
@@ -214,7 +247,7 @@ void gcpWidgetData::Copy(GtkClipboard* clipboard)
 		if ((child = (*i)->Save (pXmlDoc)))
 			xmlAddChild ((*pDoc)->children, child);
 	gcpApplication* App = View->GetDoc()->GetApplication();
-	gtk_clipboard_set_with_data(clipboard, targets, 2, (GtkClipboardGetFunc)on_get_data, (GtkClipboardClearFunc)on_clear_data, App);
+	gtk_clipboard_set_with_data(clipboard, export_targets, 7, (GtkClipboardGetFunc)on_get_data, (GtkClipboardClearFunc)on_clear_data, App);
 	gtk_clipboard_request_contents(clipboard, gdk_atom_intern ("TARGETS", FALSE),  (GtkClipboardReceivedFunc)on_receive_targets, App);
 }
 
