@@ -422,7 +422,7 @@ static void on_length_changed (GtkSpinButton *btn, gcpArrowTool *tool)
 GtkWidget *gcpArrowTool::GetPropertyPage ()
 {
 	bool show_all = m_ArrowType == gcpReversibleArrow || m_ArrowType == gcpFullReversibleArrow;
-	GladeXML *xml = glade_xml_new (DATADIR"/gchempaint-unstable/ui/arrowtool.glade", (show_all? "arrow-box": "length-box"), GETTEXT_PACKAGE);
+	GladeXML *xml = glade_xml_new (DATADIR"/gchempaint/ui/arrowtool.glade", (show_all? "arrow-box": "length-box"), GETTEXT_PACKAGE);
 	if (show_all) {
 		GtkTable *table = GTK_TABLE (glade_xml_get_widget (xml, "heads-table"));
 		GnomeCanvas *canvas = GNOME_CANVAS (gnome_canvas_new_aa ());
