@@ -4,7 +4,7 @@
  * GChemPaint atoms plugin
  * chargetool.cc 
  *
- * Copyright (C) 2003-2005 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2003-2007 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -30,6 +30,7 @@
 #include "lib/theme.h"
 #include "libgcpcanvas/gcp-canvas-group.h"
 #include "libgcpcanvas/gcp-canvas-pango.h"
+#include <glib/gi18n-lib.h>
 #include <math.h>
 
 gcpChargeTool::gcpChargeTool(gcpApplication *App, string Id): gcpTool(App, Id)
@@ -139,25 +140,25 @@ bool gcpChargeTool::OnClicked()
 		switch (align) {
 		case -2:
 			xc = x + m_ChargeTWidth / 2. - Theme->GetChargeSignSize ();
-			y += Theme->GetChargeSignHeight () / 2.;
+			y += Theme->GetChargeSignSize () / 2.;
 			break;
 		case -1:
-			xc = x - Theme->GetChargeSignSize () -1.;
+			xc = x - Theme->GetChargeSignSize () - Theme->GetPadding ();
 			break;
 		case 0:
 		case -3:
 			xc = x + m_ChargeTWidth / 2. - Theme->GetChargeSignSize ();
 			break;
 		case 1:
-			xc = x + m_ChargeWidth + 1.;
+			xc = x + m_ChargeWidth + Theme->GetPadding ();
 			break;
 		case 2:
 			xc = x + m_ChargeTWidth / 2. - Theme->GetChargeSignSize ();
-			y -= Theme->GetChargeSignHeight () / 2.;
+			y -= Theme->GetChargeSignSize () / 2.;
 			break;
 		}
 		x = xc - 1.;
-		yc = y - Theme->GetChargeSignHeight () / 2. + Theme->GetChargeYAlign () - Theme->GetChargeSignSize () + 1.;
+		yc = y - Theme->GetChargeSignSize () / 2.;
 		m_x1 = x;
 		m_y1 = y;
 		m_pItem = gnome_canvas_item_new (
@@ -346,20 +347,20 @@ void gcpChargeTool::OnDrag()
 			switch (align) {
 			case -2:
 				x += m_ChargeTWidth / 2. - Theme->GetChargeSignSize () - 1.;
-				y += Theme->GetChargeSignHeight () / 2.;
+				y += Theme->GetChargeSignSize () / 2.;
 				break;
 			case -1:
-				x-= Theme->GetChargeSignSize () + 2.;
+				x-= Theme->GetChargeSignSize () + Theme->GetPadding ();
 				break;
 			case -3:
 				x += m_ChargeTWidth / 2. - Theme->GetChargeSignSize () - 1.;
 				break;
 			case 1:
-				x += m_ChargeWidth + 2.;
+				x += m_ChargeWidth + Theme->GetPadding ();
 				break;
 			case 2:
 				x += m_ChargeTWidth / 2. - Theme->GetChargeSignSize () - 1.;
-				y -= Theme->GetChargeSignHeight () / 2.;
+				y -= Theme->GetChargeSignSize () / 2.;
 				break;
 			}
 			gnome_canvas_item_move (m_pItem, x - m_x1, y - m_y1);
