@@ -4,7 +4,7 @@
  * GChemPaint bonds plugin
  * chaintool.cc
  *
- * Copyright (C) 2006 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2006-2007 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -31,6 +31,7 @@
 #include "lib/atom.h"
 #include "lib/bond.h"
 #include "lib/theme.h"
+#include <glib/gi18n-lib.h>
 
 gcpChainTool::gcpChainTool(gcpApplication *App): gcpTool (App, "Chain")
 {
@@ -334,7 +335,7 @@ void gcpChainTool::SetLength (double length)
 
 GtkWidget *gcpChainTool::GetPropertyPage ()
 {
-	GladeXML *xml = glade_xml_new (DATADIR"/gchempaint-unstable/ui/chain.glade", "chain", GETTEXT_PACKAGE);
+	GladeXML *xml = glade_xml_new (DATADIR"/gchempaint/ui/chain.glade", "chain", GETTEXT_PACKAGE);
 	m_LengthBtn = GTK_SPIN_BUTTON (glade_xml_get_widget (xml, "bond-length"));
 	g_signal_connect (m_LengthBtn, "value-changed", G_CALLBACK (on_length_changed), this);
 	m_AngleBtn = GTK_SPIN_BUTTON (glade_xml_get_widget (xml, "bond-angle"));
