@@ -767,7 +767,7 @@ void gcpCycleTool::SetLength (double length)
 
 GtkWidget *gcpCycleTool::GetPropertyPage ()
 {
-	GladeXML *xml = glade_xml_new (DATADIR"/gchempaint-unstable/ui/cycle.glade", "cycle", GETTEXT_PACKAGE);
+	GladeXML *xml = glade_xml_new (DATADIR"/gchempaint/ui/cycle.glade", "cycle", GETTEXT_PACKAGE);
 	m_LengthBtn = GTK_SPIN_BUTTON (glade_xml_get_widget (xml, "bond-length"));
 	g_signal_connect (m_LengthBtn, "value-changed", G_CALLBACK (on_length_changed), this);
 	m_MergeBtn = GTK_TOGGLE_BUTTON (glade_xml_get_widget (xml, "merge"));
@@ -808,7 +808,7 @@ static void on_size_changed (GtkSpinButton *button, gcpNCycleTool *tool)
 
 GtkWidget *gcpNCycleTool::GetPropertyPage ()
 {
-	GladeXML *xml = glade_xml_new (DATADIR"/gchempaint-unstable/ui/cyclen.glade", "cycle", GETTEXT_PACKAGE);
+	GladeXML *xml = glade_xml_new (DATADIR"/gchempaint/ui/cyclen.glade", "cycle", GETTEXT_PACKAGE);
 	m_LengthBtn = GTK_SPIN_BUTTON (glade_xml_get_widget (xml, "bond-length"));
 	g_signal_connect (m_LengthBtn, "value-changed", G_CALLBACK (on_length_changed), NULL);
 	m_MergeBtn = GTK_TOGGLE_BUTTON (glade_xml_get_widget (xml, "merge"));
